==> Queue-DBI-2.5.2.tar.gz: Queue-DBI-2.5.2/README.md <==
Queue-DBI
=========

[![Build Status](https://travis-ci.org/guillaumeaubert/Queue-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/Queue-DBI)

A queueing module with an emphasis on safety, using DBI as a storage system
for queued data.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Queue::DBI


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Queue-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Queue-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Queue-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/Queue-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2013 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/

==> Queue-DBI-v2.6.1.tar.gz: Queue-DBI-v2.6.1/README.md <==
Queue-DBI
=========

[![Build Status](https://travis-ci.org/guillaumeaubert/Queue-DBI.png?branch=master)](https://travis-ci.org/guillaumeaubert/Queue-DBI)
[![Coverage Status](https://coveralls.io/repos/guillaumeaubert/Queue-DBI/badge.png?branch=master)](https://coveralls.io/r/guillaumeaubert/Queue-DBI?branch=master)

A queueing module with an emphasis on safety, using DBI as a storage system
for queued data.


INSTALLATION
------------

To install this module, run the following commands:

	perl Build.PL
	./Build
	./Build test
	./Build install


SUPPORT AND DOCUMENTATION
-------------------------

After installing, you can find documentation for this module with the
perldoc command.

	perldoc Queue::DBI


You can also look for information at:

 * [GitHub's request tracker (report bugs here)]
   (https://github.com/guillaumeaubert/Queue-DBI/issues)

 * [AnnoCPAN, Annotated CPAN documentation]
   (http://annocpan.org/dist/Queue-DBI)

 * [CPAN Ratings]
   (http://cpanratings.perl.org/d/Queue-DBI)

 * [MetaCPAN]
   (https://metacpan.org/release/Queue-DBI)


LICENSE AND COPYRIGHT
---------------------

Copyright (C) 2009-2014 Guillaume Aubert

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License version 3 as published by the Free
Software Foundation.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see http://www.gnu.org/licenses/
